# Roadmap

- Automatically remove Nodes on Netbox when removed on Promox (as it already happens with Virtual Machines and Containers)
- Add **individual update of VM/CT's and Nodes** (currently is only possible to update all at once)
- **Create virtual machines and containers directly on Netbox**, having no need to access Proxmox GUI.
- Add **'Console'** button to enable console access to virtual machines
- Full adoption of **FastAPI framework**
- **Background Jobs to sync data between the systems**
- Add **periodic update of the whole environment** so that the user does not need to manually click the update button.
- Improve Documentation
- Translate Documentation to Portuguese (pt-br) for brazilian community
- **Multi-Cluster suppport**

If you wish to have another feature or functionality not present today and not mentioned here, checkout **[Issues](https://github.com/netdevopsbr/netbox-proxbox/issues)** and/or **[Discussions](https://github.com/orgs/netdevopsbr/discussions)** to view if there's already ongoing work. If not, feel free to start **opening a discussion** and expects feedback from community so that it is approved and transferred to GitHub Issues.